pub(crate) fn effective_config_report(
config: &AtlasMapConfig,
) -> EffectiveConfigReportExpand description
Build the effective configuration report used by agents and docs.
pub(crate) fn effective_config_report(
config: &AtlasMapConfig,
) -> EffectiveConfigReportBuild the effective configuration report used by agents and docs.