pub(crate) fn lint_map(
config: &AtlasMapConfig,
options: LintOptions,
) -> Result<(String, i32), AtlasMapError>Expand description
Lint the atlas map and return a report plus exit code.
pub(crate) fn lint_map(
config: &AtlasMapConfig,
options: LintOptions,
) -> Result<(String, i32), AtlasMapError>Lint the atlas map and return a report plus exit code.