pub(crate) fn load_atlas_config_for_root(
root: &Path,
) -> Result<AtlasMapConfig, AtlasMapError>Expand description
Load atlas map configuration for an explicit project root.
pub(crate) fn load_atlas_config_for_root(
root: &Path,
) -> Result<AtlasMapConfig, AtlasMapError>Load atlas map configuration for an explicit project root.